ObjData

Struct ObjData 

pub struct ObjData {
    pub position: Vec<[f32; 3]>,
    pub texture: Vec<[f32; 2]>,
    pub normal: Vec<[f32; 3]>,
    pub objects: Vec<Object>,
    pub material_libs: Vec<Mtl>,
}
The data model associated with each Obj file.

Fields

position: Vec<[f32; 3]>

Vertex positions.

texture: Vec<[f32; 2]>

2D texture coordinates.

normal: Vec<[f32; 3]>

A set of normals.

objects: Vec<Object>

A collection of associated objects indicated by o, as well as the default object at the top level.

material_libs: Vec<Mtl>

The set of all mtllib references to .mtl files.

Implementations

Source

impl ObjData

pub fn save(&self, path: impl AsRef<Path>) -> Result<(), ObjError>

Save the current ObjData at the given file path as well as any associated .mtl files.

If a file already exists, it will be overwritten.

pub fn save_mtls(&self, base_dir: impl AsRef<Path>) -> Result<(), ObjError>

Save all material libraries referenced in this Obj to the given base directory.

pub fn save_mtls_with_fn<W>( &self, base_dir: &Path, resolve: impl FnMut(&Path, &str) -> Result<W, Error>, ) -> Result<(), ObjError>
where W: Write,

Save all material libraries referenced in this Obj struct according to resolve.

pub fn write_to_buf(&self, out: &mut impl Write) -> Result<(), ObjError>

Serialize this Obj into the given writer.

Source

impl ObjData

pub fn load_buf<R>(input: R) -> Result<ObjData, ObjError>
where R: Read,

pub fn load_buf_with_config<R>( input: R, config: LoadConfig, ) -> Result<ObjData, ObjError>
where R: Read,