pub struct Coordinates {
pub x: IOBuffer,
pub y: IOBuffer,
pub z: IOBuffer,
}Expand description
Point coordinates on a RectilinearGrid corresponding to x, y and z axes.
Coordinates for an extent are specified by the ordinate along each axis for each integer value
in the extent’s range. This contains three IOBuffers describing the ordinates along
the x-y-z axes, respectively.
This struct corresponds to the Coordinates element in XML formats.
Fields
x: IOBufferPoint coordinates along the x axis.
y: IOBufferPoint coordinates along the y axis.
z: IOBufferPoint coordinates along the z axis.