pub type HValueRef<'a> = ValueRef<'a, AttributeValueHashVTable>;Expand description
A reference to a value stored at an indirect attribute at some index.
Aliased Type
pub struct HValueRef<'a> { /* private fields */ }pub type HValueRef<'a> = ValueRef<'a, AttributeValueHashVTable>;A reference to a value stored at an indirect attribute at some index.
pub struct HValueRef<'a> { /* private fields */ }