pub struct QuadMesh<T>where
T: Real,{
pub vertex_positions: IntrinsicAttribute<[T; 3], VertexIndex>,
pub indices: IntrinsicAttribute<[usize; 4], FaceIndex>,
pub vertex_attributes: HashMap<String, Attribute<VertexIndex>>,
pub face_attributes: HashMap<String, Attribute<FaceIndex>>,
pub face_vertex_attributes: HashMap<String, Attribute<FaceVertexIndex>>,
pub face_edge_attributes: HashMap<String, Attribute<FaceEdgeIndex>>,
pub attribute_value_cache: HashSet<Value<MaybeUninit<usize>, AttributeValueHashVTable>>,
}Fields
vertex_positions: IntrinsicAttribute<[T; 3], VertexIndex>Vertex positions.
indices: IntrinsicAttribute<[usize; 4], FaceIndex>Quadruples of indices into vertices representing quadrilaterals.
vertex_attributes: HashMap<String, Attribute<VertexIndex>>Vertex attributes.
face_attributes: HashMap<String, Attribute<FaceIndex>>Quad attributes.
face_vertex_attributes: HashMap<String, Attribute<FaceVertexIndex>>Quad vertex attributes.
face_edge_attributes: HashMap<String, Attribute<FaceEdgeIndex>>Quad edge attributes.
attribute_value_cache: HashSet<Value<MaybeUninit<usize>, AttributeValueHashVTable>>Indirect attribute value cache
Implementations
Sourceimpl<T> QuadMesh<T>where
T: Real,
impl<T> QuadMesh<T>where
T: Real,
Sourcepub fn merge_with_vertex_source<'a, I>(
meshes: I,
source_attrib: &str,
) -> Result<QuadMesh<T>, Error>where
I: IntoIterator<Item = &'a QuadMesh<T>>,
pub fn merge_with_vertex_source<'a, I>(
meshes: I,
source_attrib: &str,
) -> Result<QuadMesh<T>, Error>where
I: IntoIterator<Item = &'a QuadMesh<T>>,
Merge a iterator of meshes into a single distinct mesh.
This version of merge accepts an attribute name for the source index on vertices.
The mesh vertices will be merged in the order given by the source attribute. This
is useful when merging previously split up meshes. The source attribute needs to
have type usize.
If the source attribute does not exist in at least one of the given meshes, then
None is returned and the merge is aborted.
This is a non-destructive merge — both original meshes remain intact. This also means that this way of merging is somewhat more expensive than a merge without any source indices.
Sourceimpl<T> QuadMesh<T>where
T: Real,
impl<T> QuadMesh<T>where
T: Real,
pub fn new(verts: Vec<[T; 3]>, indices: Vec<[usize; 4]>) -> QuadMesh<T>
Sourcepub fn face_iter_mut(&mut self) -> IterMut<'_, [usize; 4]>
pub fn face_iter_mut(&mut self) -> IterMut<'_, [usize; 4]>
Iterate mutably over each face.
Sourcepub fn reversed(self) -> QuadMesh<T>
pub fn reversed(self) -> QuadMesh<T>
Reverse the order of each polygon in this mesh. This is the consuming version of the
reverse method.
Sourcepub fn sort_vertices_by_key<K, F>(&mut self, f: F)
pub fn sort_vertices_by_key<K, F>(&mut self, f: F)
Sort vertices by the given key values.