pub trait Pod:
Sized
+ 'static
+ Copy
+ Send
+ Sync
+ Any { }Expand description
Plain old data trait. Types that implement this trait contain no references and can be copied
with memcpy. The additional Any trait lets us inspect the type more easily.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.